# Model Purpose and General Information

This repository holds a Python package named pymechanism, which can be used to simulate the H2Global mechanism.

Version 1.0 of this package was published on PyPI on 28/02/2024.

# Installation

# Workflow

# Testing
